Changelog
=========

master
------

v0.4.1
------

Fixed bug in size calculation


v0.4.1
------

- Added custom user agent

v0.4.0
------

- (`#10 <https://gitlab.com/magicc/esgf_scraper/merge_requests/10>`_) Add --verify flag to search command and removed verify command

v0.3.1
------

- Logging messages during download

v0.3.0
------

- (`#9 <https://gitlab.com/magicc/esgf_scraper/merge_requests/9>`_) Migrated to using a custom handler for downloading ESGF files. Replaces the scrapy spider which was used previously.

v0.2.2
------

- Requeue not downloaded items after a search

v0.2.1
------

- Set ``SCRAPY_SETTINGS_MODULE`` environment variable in cli
- Don't raise an exception on duplicate search results

v0.2.0
------
- Added --downloaded, --not-downloaded flags to the ``verify`` command
- Renamed ``data_filters`` config item to ``filters``
- (`#8 <https://gitlab.com/magicc/esgf_scraper/merge_requests/8>`_) Move to use click for cli. Also added the queues cli command
- (`#7 <https://gitlab.com/magicc/esgf_scraper/merge_requests/7>`_) Extend `list` cli capabilities

v0.1.2
------

- Fixed missing ``esgf_scraper.ext`` module in source distributions
- (`#6 <https://gitlab.com/magicc/esgf_scraper/merge_requests/6>`_) Added ``database_url`` configuration value to specify a custom database location.

v0.1.1
------

- Fix versioning issue

v0.1.0
------

- (`#5 <https://gitlab.com/magicc/esgf_scraper/merge_requests/5>`_) Using isort
- (`#4 <https://gitlab.com/magicc/esgf_scraper/merge_requests/4>`_) Began enforcing code standards
- (`#3 <https://gitlab.com/magicc/esgf_scraper/merge_requests/3>`_) Added autogenerated documentation
- (`#2 <https://gitlab.com/magicc/esgf_scraper/merge_requests/2>`_) Began using Gitlab's CI for running tests on every push
- Initial development

